@@ -60,9 +60,14 @@ class SimpleTree:
         for list_name in self.header_simple.keys(): self.header_simple[list_name]=list(set(self.header_simple[list_name]))
         return
 
-    def discover(self,options):
+    def ask(self,options):
         #Load header:
-        self.header=json.load(open(options.in_diagnostic_headers_file,'r'))['header']
+        try:
+            self.header=json.load(open(options.in_diagnostic_headers_file,'r'))['header']
+        except ValueError as e:
+            print 'The input diagnostic file '+options.in_diagnostic_headers_file+' does not conform to JSON standard. Make sure to check its syntax'
+            raise
+
         #Simplify the header:
         self.union_header()
 
@@ -71,6 +76,13 @@ class SimpleTree:
                 print field_name
             return
         else:
+            simulations_list=discover.discover_simulations_recursive(self,options,self.drs.simulations_desc)
+            print "This is a list of simulations that COULD satisfy the query:"
+            for simulation in simulations_list:
+                print ','.join(simulation)
+            print "cdb_query will now attempt to confirm that these simulations have all the requested variables."
+            print "This can take some time. Please abort if there are not enough simulations for your needs."
+
             if options.num_procs==1:
                 filepath=discover.discover(self,options)
                 try:
@@ -88,7 +100,7 @@ class SimpleTree:
                 output.close()
         return
 
-    def optimset(self,options):
+    def validate(self,options):
         self.load_header(options)
         #if options.data_nodes!=None:
         #    self.header['data_node_list']=options.data_nodes
@@ -133,13 +145,13 @@ class SimpleTree:
             output.close()
         return
 
-    def remote_retrieve(self,options):
+    def download(self,options):
         output=netCDF4.Dataset(options.out_diagnostic_netcdf_file,'w')
         retrieval_function='retrieve_path_data'
         self.remote_retrieve_and_download(options,output,retrieval_function)
         return
 
-    def download(self,options):
+    def download_raw(self,options):
         output=options.out_destination
 
         #Describe the tree pattern:
